/**
 * Value object representing an API key
 */
export declare class ApiKey {
    private readonly VALUE;
    constructor(value: string);
    /**
     * Check if two API keys are equal
     * @param {ApiKey} other - The other API key to compare with
     * @returns {boolean} True if the API keys are equal
     */
    equals(other: ApiKey): boolean;
    /**
     * Get the API key value
     * @returns {string} The API key value
     */
    getValue(): string;
    /**
     * Check if the API key is valid
     * @returns {boolean} True if the API key appears to be valid
     */
    isValid(): boolean;
    /**
     * Get a redacted version of the API key for display
     * @returns {string} Redacted API key
     */
    toRedacted(): string;
}
