'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var container = require('./infrastructure/di/container.js');
var commitizen_adapter = require('./presentation/commitizen.adapter.js');
require('dotenv/config');
var configureLlm_useCase = require('./application/use-case/configure-llm.use-case.js');
var generateCommitMessage_useCase = require('./application/use-case/generate-commit-message.use-case.js');
var manualCommit_useCase = require('./application/use-case/manual-commit.use-case.js');
var validateCommitMessage_useCase = require('./application/use-case/validate-commit-message.use-case.js');
var commitMessage_entity = require('./domain/entity/commit-message.entity.js');
var llmConfiguration_entity = require('./domain/entity/llm-configuration.entity.js');
var anthropicModel_enum = require('./domain/enum/anthropic-model.enum.js');
var awsBedrockModel_enum = require('./domain/enum/aws-bedrock-model.enum.js');
var azureOpenaiModel_enum = require('./domain/enum/azure-openai-model.enum.js');
var commitMode_enum = require('./domain/enum/commit-mode.enum.js');
var googleModel_enum = require('./domain/enum/google-model.enum.js');
var llmProvider_enum = require('./domain/enum/llm-provider.enum.js');
var logLevel_enum = require('./domain/enum/log-level.enum.js');
var ollamaModel_enum = require('./domain/enum/ollama-model.enum.js');
var openaiModel_enum = require('./domain/enum/openai-model.enum.js');
var apiKey_valueObject = require('./domain/value-object/api-key.value-object.js');
var commitBody_valueObject = require('./domain/value-object/commit-body.value-object.js');
var commitHeader_valueObject = require('./domain/value-object/commit-header.value-object.js');

// Initialize the DI container
container.createAppContainer();
// Create adapter instance
const adapter = new commitizen_adapter.CommitizenAdapter();
/**
 * Commitizen adapter entry point
 * This function is called by Commitizen when running `git cz`
 * It delegates to the CommitizenAdapter to handle the interactive commit process
 * @param {unknown} inquirerInstance - The inquirer instance provided by Commitizen
 * @param {(message: string) => void} commit - Callback function to execute the commit with the generated message
 * @returns {Promise<void>} Promise that resolves when the commit process is complete
 */
async function prompter(inquirerInstance, commit) {
    return adapter.prompter(inquirerInstance, commit);
}
// Export the prompter function for Commitizen
var index = {
    prompter,
};

exports.ConfigureLLMUseCase = configureLlm_useCase.ConfigureLLMUseCase;
exports.GenerateCommitMessageUseCase = generateCommitMessage_useCase.GenerateCommitMessageUseCase;
exports.ManualCommitUseCase = manualCommit_useCase.ManualCommitUseCase;
exports.ValidateCommitMessageUseCase = validateCommitMessage_useCase.ValidateCommitMessageUseCase;
exports.CommitMessage = commitMessage_entity.CommitMessage;
exports.LLMConfiguration = llmConfiguration_entity.LLMConfiguration;
Object.defineProperty(exports, "EAnthropicModel", {
    enumerable: true,
    get: function () { return anthropicModel_enum.EAnthropicModel; }
});
Object.defineProperty(exports, "EAWSBedrockModel", {
    enumerable: true,
    get: function () { return awsBedrockModel_enum.EAWSBedrockModel; }
});
Object.defineProperty(exports, "EAzureOpenAIModel", {
    enumerable: true,
    get: function () { return azureOpenaiModel_enum.EAzureOpenAIModel; }
});
Object.defineProperty(exports, "ECommitMode", {
    enumerable: true,
    get: function () { return commitMode_enum.ECommitMode; }
});
Object.defineProperty(exports, "EGoogleModel", {
    enumerable: true,
    get: function () { return googleModel_enum.EGoogleModel; }
});
Object.defineProperty(exports, "ELLMProvider", {
    enumerable: true,
    get: function () { return llmProvider_enum.ELLMProvider; }
});
Object.defineProperty(exports, "ELogLevel", {
    enumerable: true,
    get: function () { return logLevel_enum.ELogLevel; }
});
Object.defineProperty(exports, "EOllamaModel", {
    enumerable: true,
    get: function () { return ollamaModel_enum.EOllamaModel; }
});
Object.defineProperty(exports, "EOpenAIModel", {
    enumerable: true,
    get: function () { return openaiModel_enum.EOpenAIModel; }
});
exports.ApiKey = apiKey_valueObject.ApiKey;
exports.CommitBody = commitBody_valueObject.CommitBody;
exports.CommitHeader = commitHeader_valueObject.CommitHeader;
exports.default = index;
exports.prompter = prompter;
//# sourceMappingURL=index.js.map
