/**
 * Value object representing a commit message header
 */
export declare class CommitHeader {
    private readonly SCOPE;
    private readonly SUBJECT;
    private readonly TYPE;
    constructor(type: string, subject: string, scope?: string);
    /**
     * Check if two headers are equal
     * @param {CommitHeader} other - The other commit header to compare with
     * @returns {boolean} True if the headers are equal
     */
    equals(other: CommitHeader): boolean;
    /**
     * Get the commit scope
     * @returns {string | undefined} The commit scope or undefined
     */
    getScope(): string | undefined;
    /**
     * Get the commit subject
     * @returns {string} The commit subject
     */
    getSubject(): string;
    /**
     * Get the commit type
     * @returns {string} The commit type
     */
    getType(): string;
    /**
     * Format the header as a string
     * @returns {string} The formatted header
     */
    toString(): string;
}
